# EvBreadcrumb

Simple breadcrumb component and view element for rendering breadcrumb trails.

Default template has been setup to conform with the frontend snippets breadcrumb example.


## Install

Add `EvBreadcrumb` to your `CakePlugin::loadAll()` in `app/Config/bootstrap.php`.

Next you need to load the component, this can be done within `app/Controller/AppController.php` by using the following code, if the beforeFilter method already exists, just copy the Component load line:

	public function beforeFilter()
	{
		parent::beforeFilter();

		$this->Breadcrumb = $this->Components->load('EvBreadcrumb.Breadcrumb');
	}

### Configs

You can set some of the default values here on load if needed, by adding a second array to the `load` method. This can be used to override the default separator or add a starting link (e.g. the home link).

Available options are:

* `links` - This should be a multi-dimensional array with the sub-array containing `text` element and an `url` element.
*  `backLink` - This should be an array containing `text` element and `url` element. This is used to float right of the breadcrumb trails for a "Back to XXX" style link.
*  `separator` - This is a string to be used as a separator for the elements, this will get added to the `LI` tag after the `A` tag. `<li><a href="#">My Link</a>SEPARATOR</li>`

n.b. `url` element is passed to `Html->link()` so can be either a string or Routing Array.

Full Example:

		$this->Breadcrumb = $this->Components->load(
			'EvBreadcrumb.Breadcrumb',
			array(
				'links' => array(
					array(
						'text' => 'Home',
						'url' => array(
							'plugin' => false,
							'controller' => 'ev_core_pages',
							'action' => 'view',
							1
						),
						'options' => array(
							'escape' => false
						)
					)
				),
				'backLink' => array(
					'text' => 'Back to Homepage',
					'url' => '/',
					'options' => array(
						'escape' => false
					)
				),
				'separator' => ' &raquo;'
			)
		);


## Usage

### Main Breadcrumb Links

Assuming the component has been loaded as above you can use the following methods to add links to the breadcrumb

	$this->Breadcrumb->links(
		'Link Text',
		array(
			'controller' => 'pages',
			'action' => 'view',
			1
		),
		array(
			'escape' => false
		)
	);

For the last item in a breadcrumb, just simply omit the second parameter with the above call.

	$this->Breadcrumb->links('Link Text');

### Back Link

If you wish to add a back link on the fly use the `backLink` Method.

	$this->Breadcrumb->backLink(
		'Back to Categories',
		array(
			'controller' => 'categories',
			'action' => 'view',
			1
		)
	);

### Separator

If you wish to amend the separator on the fly, this can be done with the `separator` method.

	$this->Breadcrumb->separator(' &raquo;');


## Retrieving Data

The same methods above can be used to retrieve the current data. Omit all the parameters to return the links / back link / separator.

	$links = $this->Breadcrumb->links(); // Array of all the links currently added
	$backLink = $this->Breadcrumb->backLink(); // Array containing the back link info
	$separator = $this->Breadcrumb->separator(); // String containing the separator

## Clear Links

Should you need to clear the link array, you can do so with the following method.

	$this->Breadcrumb->clearLinks();

## Template

Assuming the HTML has been done to correspond with the Breadcrumb snippet in the frontend-snippets repo, all that you need to do is call the element.

	<?php echo $this->element('EvBreadcrumb.breadcrumb'); ?>

If changes need to occur, the template can be overwritten using the standard plugin template overriding methods.
